@@ -6,5 +6,9 @@
 
 
 import logging
+import sys
 
-LOG = logging.getLogger()
+logging.basicConfig(level=logging.DEBUG,
+                    format='%(asctime)s %(levelname)s %(message)s')
+
+LOG = logging.getLogger('root')
