@@ -4,6 +4,7 @@
 # (C) 2007, ZOPYX Ltd & Co. KG, Tuebingen, Germany
 ##########################################################################
 
+import os
 import sys
 import tempfile
 
@@ -29,6 +30,10 @@ def runcmd(cmd):
 
     else:
 
+        if os.environ.has_key('USE_OS_SYSTEM'):
+            status = os.system(cmd)
+            return status, ''
+
         stdin = open('/dev/null')
         stdout = stderr = PIPE
 
